summaryrefslogtreecommitdiff
path: root/src/thenewpoketext/UnicodeParser.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/thenewpoketext/UnicodeParser.java')
-rwxr-xr-xsrc/thenewpoketext/UnicodeParser.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/thenewpoketext/UnicodeParser.java b/src/thenewpoketext/UnicodeParser.java
index 2f0b008..2026ca7 100755
--- a/src/thenewpoketext/UnicodeParser.java
+++ b/src/thenewpoketext/UnicodeParser.java
@@ -3,7 +3,7 @@ package thenewpoketext;
/*----------------------------------------------------------------------------*/
/*-- UnicodeParser.java - maintains the poke<->unicode text table --*/
/*-- Code loosely derived from "thenewpoketext", copyright (C) loadingNOW --*/
/*-- Ported to Java and customized by Dabomstew --*/
/*----------------------------------------------------------------------------*/
import java.io.FileNotFoundException;
@@ -11,7 +11,7 @@ import java.util.HashMap;
import java.util.Map;
import java.util.Scanner;
-import com.dabomstew.pkrandom.FileFunctions;
+import com.rafa_99.pkrandom.FileFunctions;
public class UnicodeParser {
@@ -3,7 +3,7 @@ package thenewpoketext;
/*-- UnicodeParser.java - maintains the poke<->unicode text table --*/
/*-- Code loosely derived from "thenewpoketext", copyright (C) loadingNOW --*/
-/*-- Ported to Java and customized by Dabomstew --*/
+/*-- Ported to Java and customized by rafa_99 --*/
/*----------------------------------------------------------------------------*/
import java.io.FileNotFoundException;